summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2014-06-14 03:23:54 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2014-06-14 03:23:54 (GMT)
commitec408ef08317074029b0dc631d526c4bb45984e6 (patch)
tree5d3bb59c29dd09713abde8f22d4dc0f875ae9e21 /src
parente23830d29f6623c0482a06b69ae2862bde1e9e33 (diff)
downloadhdf5-ec408ef08317074029b0dc631d526c4bb45984e6.zip
hdf5-ec408ef08317074029b0dc631d526c4bb45984e6.tar.gz
hdf5-ec408ef08317074029b0dc631d526c4bb45984e6.tar.bz2
[svn-r25283] Description:
Correct error in new hyperslab selection test to use the right # of dimensions for start/stride/count/block arrays. Also, switch H5Sselect_select to H5Smodify_select. Tested on: MacOSX/64 10.9.3 (amazon) w/gcc 4.9.1, OpenMPI, C++, FORTRAN & threadsafe (Too minor to require h5committest)
Diffstat (limited to 'src')
-rw-r--r--src/H5Shyper.c22
-rw-r--r--src/H5Spublic.h2
2 files changed, 12 insertions, 12 deletions
diff --git a/src/H5Spublic.h b/src/H5Spublic.h
index dd3099f..105530a 100644
--- a/src/H5Spublic.h
+++ b/src/H5Spublic.h
@@ -118,7 +118,7 @@ H5_DLL hid_t H5Scombine_hyperslab(hid_t space_id, H5S_seloper_t op,
const hsize_t _stride[],
const hsize_t count[],
const hsize_t _block[]);
-H5_DLL herr_t H5Sselect_select(hid_t space1_id, H5S_seloper_t op,
+H5_DLL herr_t H5Smodify_select(hid_t space1_id, H5S_seloper_t op,
hid_t space2_id);
H5_DLL hid_t H5Scombine_select(hid_t space1_id, H5S_seloper_t op,
hid_t space2_id);
diff --git a/src/H5Shyper.c b/src/H5Shyper.c
index 37fef93..1484c95 100644
--- a/src/H5Shyper.c
+++ b/src/H5Shyper.c
@@ -86,7 +86,7 @@ static herr_t H5S_fill_in_hyperslab(H5S_t *old_space, H5S_seloper_t op,
static herr_t H5S_fill_in_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2,
H5S_t **result);
static H5S_t *H5S_combine_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2);
-static herr_t H5S_select_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2);
+static herr_t H5S_modify_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2);
static herr_t H5S_hyper_get_seq_list_gen(const H5S_t *space, H5S_sel_iter_t *iter,
size_t maxseq, size_t maxelem, size_t *nseq, size_t *nelem, hsize_t *off,
size_t *len);
@@ -7845,7 +7845,7 @@ H5Scombine_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id)
/* Note: currently, the offset of each dataspace is ignored */
#if 0
/* Check that both dataspaces have the same offset */
/* Same note as in H5Sselect_select */
for(u=0; u<space1->extent.rank; u++) {
if(space1->select.offset[u] != space2->select.offset[u])
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "dataspaces not same offset")
@@ -7873,9 +7873,9 @@ done:
/*-------------------------------------------------------------------------
- * Function: H5S_select_select
+ * Function: H5S_modify_select
*
* Purpose: Internal version of H5Sselect_select().
*
* Return: New dataspace on success/NULL on failure
*
@@ -7888,7 +7888,7 @@ done:
*-------------------------------------------------------------------------
*/
static herr_t
-H5S_select_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2)
+H5S_modify_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2)
{
herr_t ret_value = SUCCEED; /* Return value */
@@ -7930,17 +7930,17 @@ H5S_select_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2)
done:
FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5S_select_select() */
+} /* end H5S_modify_select() */
/*--------------------------------------------------------------------------
NAME
- H5Sselect_select
+ H5Smodify_select
PURPOSE
Refine a hyperslab selection with an operation using a second hyperslab
to modify it
USAGE
- herr_t H5Sselect_select(space1, op, space2)
+ herr_t H5Smodify_select(space1, op, space2)
hid_t space1; IN/OUT: First Dataspace ID
H5S_seloper_t op; IN: Selection operation
hid_t space2; IN: Second Dataspace ID
@@ -7956,7 +7956,7 @@ done:
REVISION LOG
--------------------------------------------------------------------------*/
herr_t
-H5Sselect_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id)
+H5Smodify_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id)
{
H5S_t *space1; /* First Dataspace */
H5S_t *space2; /* Second Dataspace */
@@ -8007,12 +8007,12 @@ H5Sselect_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id)
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "dataspaces don't have hyperslab selections")
/* Go refine the first selection */
- if(H5S_select_select(space1, op, space2) < 0)
+ if(H5S_modify_select(space1, op, space2) < 0)
HGOTO_ERROR(H5E_DATASPACE, H5E_CANTINIT, FAIL, "unable to modify hyperslab selection")
done:
FUNC_LEAVE_API(ret_value)
-} /* end H5Sselect_select() */
+} /* end H5Smodify_select() */
/*--------------------------------------------------------------------------
@@ -7845,7 +7845,7 @@ H5Scombine_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id)
#if 0
/* Check that both dataspaces have the same offset */
- /* Same note as in H5Sselect_select */
+ /* Same note as in H5Smodify_select */
for(u=0; u<space1->extent.rank; u++) {
if(space1->select.offset[u] != space2->select.offset[u])
@@ -7873,9 +7873,9 @@ done:
*
- * Purpose: Internal version of H5Sselect_select().
+ * Purpose: Internal version of H5Smodify_select().
*
* Return: New dataspace on success/NULL on failure